# Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""Settings for post-processing."""

from __future__ import annotations

from pydantic import Field

from gemseo.post.base_post_settings import BasePostSettings
from gemseo.utils.pydantic import update_field


class Robustness_Settings(BasePostSettings):  # noqa: D101, N801
    _TARGET_CLASS_NAME = "Robustness"
    stddev: float = Field(
        default=0.01,
        description="The standard deviation of the normal uncertain variable to be "
        "added to the optimal design value; expressed as a fraction of "
        "the bounds of the design variables.",
        ge=0.0,
        le=1.0,
    )


update_field(Robustness_Settings, "fig_size", default=(8.0, 5.0))
