# Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 3 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
# Contributors:
#    INITIAL AUTHORS - initial API and implementation and/or initial
#                         documentation
#        :author: Charlie Vanaret, Francois Gallard
#    OTHER AUTHORS   - MACROSCOPIC CHANGES
from __future__ import annotations

import pytest
from numpy import array
from numpy import isclose

from .utils import generate_parallel_doe


@pytest.mark.parametrize(
    "mda_class",
    ["MDAQuasiNewton", "MDANewtonRaphson", "MDAGaussSeidel"],
)
def test_parallel_doe(mda_class) -> None:
    """Test the execution of Newton methods in parallel.

    Args:
        mda_class: The specific Newton MDA to test.
    """
    obj = generate_parallel_doe(
        "MDAChain", main_mda_settings={"inner_mda_name": mda_class}
    )
    assert isclose(array([obj]), array([-608.17]), atol=1e-3, rtol=1e-3)
